package org.opengroup.osdu.register.provider.azure.subscriber;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import org.apache.http.HttpStatus;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.core.common.model.http.AppException;
import org.opengroup.osdu.core.common.model.notification.Topic;
import org.opengroup.osdu.register.provider.azure.di.AzureBootstrapConfig;
import org.opengroup.osdu.register.provider.interfaces.subscriber.ITopicsRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Repository;

import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.List;

@Repository
@Primary
public class TopicsRepositoryImpl implements ITopicsRepository {
    @Autowired
    private JaxRsDpsLog log;

    @Autowired
    private AzureBootstrapConfig config;

    private List<Topic> topics;

    public List<Topic> listMessages() {
        if (topics == null) {
            String topicName = config.getEventGridTopicName();
            Gson gson = new Gson();
            java.lang.reflect.Type listType = new TypeToken<ArrayList<Topic>>() {
            }.getType();
            topics = gson.fromJson(getFile(), listType);
            Topic topic = topics.get(0);
            topic.setName(topicName);
            topics.set(0, topic);
        }
        return topics;
    }

    private String getFile() {
        final String fileName = "topics.json";
        try {
            InputStream inputStream = new ClassPathResource(fileName).getInputStream();
            ByteArrayOutputStream result = new ByteArrayOutputStream();
            byte[] buffer = new byte[1024];
            int length;
            while ((length = inputStream.read(buffer)) != -1) {
                result.write(buffer, 0, length);
            }
            return result.toString(StandardCharsets.UTF_8.name());
        } catch (Exception e) {
            log.error("Error retrieving topics.json", e);
            throw new AppException(HttpStatus.SC_SERVICE_UNAVAILABLE, "Server error", "An unexpected error occurred");
        }
    }
}
