/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.action.model;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import javax.validation.constraints.Email;
import javax.validation.constraints.NotEmpty;
import org.hibernate.validator.constraints.URL;

import javax.validation.Valid;
import javax.validation.constraints.Pattern;

@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class CreateActionDto {

    @Pattern(regexp = "^[A-Za-z0-9-]{2,50}")
    private String id;
    @NotEmpty
    @Pattern(regexp = "^[A-Za-z0-9- ]{2,50}")
    private String name;
    @Pattern(regexp = "^[A-Za-z0-9. ]{0,255}")
    private String description;
    @URL(protocol = "https")
    private String img;
    @URL(protocol = "https")
    private String url;
    @Email
    private String contactEmail;
    @Valid
    @Builder.Default
    private Filter filter = new Filter();
}
