/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.action.services;

import com.fasterxml.jackson.databind.JsonNode;
import org.opengroup.osdu.register.action.model.Action;
import org.opengroup.osdu.register.action.model.CreateActionDto;
import org.opengroup.osdu.register.action.model.ParsedAction;
import org.opengroup.osdu.register.action.model.TestActionRequest;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.register.provider.interfaces.action.IRetrieveActionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class RetrieveActionServiceImpl implements IRetrieveActionService {

    @Autowired
    private JaxRsDpsLog logger;
    @Autowired
    private TestActionService actionService;

    @Override
    public List<Action> getActions(List<Action> actions, JsonNode record) {
        List<Action> actionsOutput = new ArrayList<>();
        for (Action action : actions) {
            ParsedAction parsedAction = this.actionService.validateRegex(getActionRequest(action, record));
            if (parsedAction.hasErrors()) {
                this.logger.warning(parsedAction.getErrors());
                continue;
            }
            action.setUrl(parsedAction.getUrl());
            actionsOutput.add(action);
        }
        return actionsOutput;
    }

    private TestActionRequest getActionRequest(Action action, JsonNode record) {
        CreateActionDto dto = new CreateActionDto();
        dto.setId(action.getId());
        dto.setDescription(action.getDescription());
        dto.setFilter(action.getFilter());
        dto.setImg(action.getImg());
        dto.setName(action.getName());
        dto.setUrl(action.getUrl());

        return new TestActionRequest(dto, record);
    }
}
