/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.ddms.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.google.cloud.Timestamp;
import org.opengroup.osdu.register.ddms.model.validators.ValidRegisteredInterfaces;
import lombok.Data;
import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;

import javax.validation.Valid;
import javax.validation.constraints.Pattern;
import java.util.HashSet;
import java.util.Optional;
import java.util.Set;

@Data
@JsonIgnoreProperties({"first"})
public class Ddms {
    @NotBlank
    @Pattern(regexp = "^[A-Za-z0-9-]{2,50}")
    private String id;

    @NotBlank
    @Pattern(regexp = "^[A-Za-z0-9- ]{2,50}")
    private String name;

    @Pattern(regexp = "^[A-Za-z0-9. ]{0,255}")
    private String description;

    @Email
    private String contactEmail;

    private Timestamp createdDateTimeEpoch = Timestamp.now();

    @ValidRegisteredInterfaces
    @Valid
    private Set<RegisteredInterface> interfaces = new HashSet<>();

    public RegisteredInterface getInterfaceByType(String type) {
        Optional<RegisteredInterface> ri = interfaces.stream()
                .filter(i -> i.getEntityType().equalsIgnoreCase(type))
                .findAny();
        return ri.isPresent() ? ri.get() : null;
    }

    public RegisteredInterface getFirst() {
        return interfaces.iterator().next();
    }
}
