/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.logging;

import org.opengroup.osdu.register.action.model.Action;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.core.common.logging.audit.AuditAction;
import org.opengroup.osdu.core.common.logging.audit.AuditPayload;
import org.opengroup.osdu.core.common.logging.audit.AuditStatus;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.register.subscriber.model.Subscription;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.context.annotation.RequestScope;

import java.util.Collections;

import static org.opengroup.osdu.core.common.logging.audit.AuditPayload.builder;

@Component
@RequestScope
public class AuditLog {

    @Autowired
    private JaxRsDpsLog logger;
    @Autowired
    private DpsHeaders dpsHeaders;

    public void createDmsSuccess(String id) {
        AuditPayload payload = builder()
                .action(AuditAction.CREATE)
                .status(AuditStatus.SUCCESS)
                .actionId("RG10001")
                .message("Registered new DDMS")
                .resources(Collections.singletonList(id))
                .user(dpsHeaders.getUserEmail())
                .build();
        writeLog(payload);
    }

    public void deleteDmsSuccess(String id) {
        AuditPayload payload = builder()
                .action(AuditAction.DELETE)
                .status(AuditStatus.SUCCESS)
                .actionId("RG10002")
                .message("Deleted DDMS")
                .resources(Collections.singletonList(id))
                .user(dpsHeaders.getUserEmail())
                .build();
        writeLog(payload);
    }

    public void createSubscriptionSuccess(Subscription subscription) {
        AuditPayload payload = builder()
                .action(AuditAction.CREATE)
                .status(AuditStatus.SUCCESS)
                .actionId("RG10003")
                .message("Create new subscription")
                .resources(Collections.singletonList(subscription.toString()))
                .user(dpsHeaders.getUserEmail())
                .build();
        writeLog(payload);
    }

    public void deleteSubscriptionSuccess(String id) {
        AuditPayload payload = builder()
                .action(AuditAction.DELETE)
                .status(AuditStatus.SUCCESS)
                .actionId("RG10004")
                .message("Deleted subscription")
                .resources(Collections.singletonList(id))
                .user(dpsHeaders.getUserEmail())
                .build();
        writeLog(payload);
    }

    public void updateSubscriptionSecretSuccess(String id) {
        AuditPayload payload = builder()
                .action(AuditAction.UPDATE)
                .status(AuditStatus.SUCCESS)
                .actionId("RG10005")
                .message("Updated subscription")
                .resources(Collections.singletonList(id))
                .user(dpsHeaders.getUserEmail())
                .build();
        writeLog(payload);
    }

    public void createActionSuccess(Action action) {
        AuditPayload payload = builder()
                .action(AuditAction.CREATE)
                .status(AuditStatus.SUCCESS)
                .actionId("RG10008")
                .message("Create new action")
                .resources(Collections.singletonList(action.toString()))
                .user(dpsHeaders.getUserEmail())
                .build();
        writeLog(payload);
    }

    public void deleteActionSuccess(String id) {
        AuditPayload payload = builder()
                .action(AuditAction.DELETE)
                .status(AuditStatus.SUCCESS)
                .actionId("RG10009")
                .message("Deleted action")
                .resources(Collections.singletonList(id))
                .user(dpsHeaders.getUserEmail())
                .build();
        writeLog(payload);
    }

    private void writeLog(AuditPayload log) {
        logger.audit(log);
    }
}
