/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.utils;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.google.common.io.Resources;
import com.reprezen.kaizen.oasparser.OpenApiParser;
import com.reprezen.kaizen.oasparser.model3.OpenApi3;
import org.opengroup.osdu.register.ddms.model.Ddms;
import org.opengroup.osdu.register.ddms.model.RegisteredInterface;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import static org.junit.Assert.assertTrue;

public class OpenApiFileUtils {

    @SuppressWarnings("unchecked")
    public static Ddms getDmsWithOpenSpec(String filePath, String type) throws IOException {
        File file = new File(Resources.getResource(filePath).getFile());
        assertTrue("Could not find resource", file.exists());
        ObjectMapper mapper = new ObjectMapper();
        Map<String, Object> schema = mapper.readValue(file, HashMap.class);

        RegisteredInterface specRegistration = new RegisteredInterface();
        specRegistration.setSchema(schema);
        specRegistration.setEntityType(type);
        Ddms ddms = new Ddms();
        ddms.getInterfaces().add(specRegistration);
        return ddms;
    }

    public static OpenApi3 getOpenApi(String filePath) throws Exception {
        return (OpenApi3) new OpenApiParser().parse(Resources.getResource(filePath), true);
    }
}