/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.utils;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.runners.MockitoJUnitRunner;

import java.net.URI;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

@RunWith(MockitoJUnitRunner.class)
public class UriResolverTest {

    @InjectMocks
    private UriResolver sut;

    @Test
    public void should_return_validUri_for_validArgs() {
        String expectedUrl = "https://subsurface.data.osdu.opengroup.org/v1/wellbore/123e4567";
        URI uri = this.sut.getUri("https://subsurface.data.osdu.opengroup.org/v1", "/wellbore/{wellboreId}", "123e4567");
        assertEquals(expectedUrl, uri.toASCIIString());

        // add slash at the end of base address
        expectedUrl = "https://subsurface.data.osdu.opengroup.org/v1/wellbore/123e4567";
        uri = this.sut.getUri("https://subsurface.data.osdu.opengroup.org/v1/", "/wellbore/{wellboreId}", "123e4567");
        assertEquals(expectedUrl, uri.toASCIIString());

        // no param given
        expectedUrl = "https://subsurface.data.osdu.opengroup.org/v1/wellbore";
        uri = this.sut.getUri("https://subsurface.data.osdu.opengroup.org/v1/", "/wellbore");
        assertEquals(expectedUrl, uri.toASCIIString());
    }

    @Test
    public void should_return_nullUri_when_mismatched_argsCount() {
        URI uri = this.sut.getUri("https://subsurface.data.osdu.opengroup.org/v1", "/wellbore/{wellboreId}/{sourceId}", "123e4567");
        assertNull(uri);
    }
}