/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.subscriber;

import com.google.gson.Gson;
import com.sun.jersey.api.client.ClientResponse;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.opengroup.osdu.register.model.Subscriber;
import org.opengroup.osdu.register.util.AzureTestUtils;
import org.opengroup.osdu.register.util.RestDescriptor;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;

import static org.junit.Assert.assertEquals;

public class TestGetSubscriberByIdApi extends GetSubscriberByIdApiTest {

    @Before
    @Override
    public void setup() throws Exception {
        this.testUtils = new AzureTestUtils();
        super.setup();
    }

    @After
    @Override
    public void tearDown() {
        this.testUtils = null;
    }

    @Test
    @Override
    public void should_return400_when_makingHttpRequestWithoutToken() throws Exception {
        ClientResponse response = descriptor.run(getId(), "");
        assertEquals(error(response.getEntity(String.class)), 403, response.getStatus());
    }

    @Override
    public void validate20XResponse(ClientResponse response, RestDescriptor descriptor) {
        String body = response.getEntity(String.class);
        Subscriber subscriber = new Gson().fromJson(body, Subscriber.class);
        String createdBy = System.getProperty("INTEGRATION_TESTER", System.getenv("INTEGRATION_TESTER"));
        String topic = System.getProperty("TEST_TOPIC_NAME", System.getenv("TEST_TOPIC_NAME"));
        assertEquals("My test listener.", subscriber.description);
        assertEquals(createdBy, subscriber.createdBy);
        assertEquals("My listener", subscriber.name);
        assertEquals(topic, subscriber.topic);
    }

    @Test
    @Override
    public void should_beAbleToRunApiInParallel() throws Exception {
        createResource();
        ExecutorService executor = Executors.newFixedThreadPool(10);
        List<Callable<ClientResponse>> tasks = new ArrayList<>();

        for (int i = 0; i < 10; i++) {
            Callable<ClientResponse> task = () -> {
                try {
                    return descriptor.run(getId(), testUtils.getOpsAccessToken());
                } catch (Exception ex) {
                    return null;
                }
            };
            tasks.add(task);
        }

        List<Future<ClientResponse>> responses = executor.invokeAll(tasks);
        executor.shutdown();
        executor.awaitTermination(300, TimeUnit.SECONDS);
        int sucessResponseCount = 0;
        for (Future<ClientResponse> future : responses) {
            if (future.get().getStatus() == expectedOkResponseCode())
                sucessResponseCount++;
        }

        deleteResource();
        assertEquals(error("Expected all successful responses. Actual " + sucessResponseCount), 10, sucessResponseCount);
    }
}
